@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Channel.tcl,v $
-# $Date: 1998/07/14 09:32:13 $
-# $Revision: 1.18.1.170 $
+# $Date: 1998/07/14 15:42:14 $
+# $Revision: 1.18.1.171 $
 #
 #
 package provide zircon 1.18
@@ -147,13 +147,14 @@ proc channel_show {this args} {
    	switch default [set nn [$net name]] {set nn IRC}	
    	foreach {wname ttl} [$this setTitles] break
    	set wndw [Window :: make [lindex $p 1]]
+	$wndw configure -cols [lindex $p 2]
 	set xc {}
 	switch [lindex $p 0] {
 	  hicaffiene -
 	  diet {
 		if {[isNotDefaultNet $net]} { append ttl "- [$net name]" }
 		set w [switchFrame \
-    		  [set wn [$wndw name]] $this $ttl -handles]
+    		  [set wn [$wndw name]] $this $ttl [$wndw nextCol] -handles]
 		set ttl "Shared Channels"
 		set del "deleteFrame [$wndw name] $this"
   		if {![$this open] || ![$this join]} {set xc "$wndw expose $this"}
@@ -780,11 +781,14 @@ proc makeCEntry {this net w chan rchan idx cdx look} {
     grid columnconfigure $w.r$idx $cdx -weight 1
     set om [frame $w.cmd -borderwidth 0]
     grid columnconfigure $om 0 -weight 1
-    scrollbar $om.hs -orient horizontal -command "$om.entry xview"
     set occ $om.entry
-    emacsEntry $occ -xscrollcommand "$om.hs set"
+    emacsEntry $occ
     grid $occ -row 0 -column 0 -sticky ew
-    grid $om.hs -row 1 -column 0 -sticky ew
+    switch -- $look {} - scroll {
+	scrollbar $om.hs -orient horizontal -command "$om.entry xview"
+	$occ configure -xscrollcommand "$om.hs set"
+	grid $om.hs -row 1 -column 0 -sticky ew
+    }
     doBindings $occ $this $chan
     if {[$this ircIImode]} { set im $zII } { set im $zNOII }
     button $om.ii -command "toggleII $this $om.ii" -image $im
