@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Control.tcl,v $
-# $Date: 1998/07/13 09:33:39 $
-# $Revision: 1.18.1.100 $
+# $Date: 1998/07/14 15:42:19 $
+# $Revision: 1.18.1.101 $
 #
 #
 package provide zircon 1.18
@@ -179,7 +179,7 @@ proc Control {args} {
     set this [makeObj Control $args]
     upvar #0 $this cdata
     set net $cdata(net)
-    set ctl [set cdata(window) [switchFrame [MainControl] $net [$net name]]]
+    set ctl [set cdata(window) [switchFrame [MainControl] $net [$net name] 0]]
     evenGrid $ctl column 0 3
     $this serverFrame $ctl
 #
@@ -483,7 +483,7 @@ proc control_buildServers {this net ctl row col} {
     global Ops zircon
     switch $zircon(serversStyle) {
     panel {
-	    set f [switchFrame $ctl.srv $net [trans servers]]
+	    set f [switchFrame $ctl.srv $net [trans servers] 0]
 	}
     pulldown {
 	    set mn [makeMB $ctl.servers "Server Information"]
@@ -601,10 +601,6 @@ proc netspaceMenu {w} {
 #
 proc addToNM {name} { addNS [MainControl].helpFrm.spaces.menu $name }
 #
-#proc delFromNM {net} {
-#    .@ctl.helpFrm.spaces.menu delete [[MainControl].helpFrm.spaces.menu index $net]
-#}
-#
 proc setUnload {name state} {
     set m [MainControl].helpFrm.spaces.menu
     set i 0
@@ -613,7 +609,7 @@ proc setUnload {name state} {
 	switch -- $name $nm break
 	incr i
     }
-    [$m entrycget $i -menu]  entryconfigure 1 -state $state
+    [$m entrycget $i -menu]  entryconfigure 1 -state $state	;# Unload
 }
 #
 proc addNS {om x} {
