@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Entry.tcl,v $
-# $Date: 1998/04/23 08:59:04 $
-# $Revision: 1.18.1.9 $
+# $Date: 1998/05/21 12:55:25 $
+# $Revision: 1.18.1.10 $
 #
 package provide zircon 1.18
 #
@@ -84,10 +84,6 @@ proc glabelEntry {t row col name opts init code} {
 #
 proc labelNumber {t name opts init code} {
     labelEntry $t $name $opts $init $code
-    bind $name.entry <KeyPress> {
-	notIdle %W
-	switch -glob -- %A { [0-9+-] { %W insert insert %A } }
-	break
-    }
+    bindtags $name.entry "$name.entry NEntry"
     return $name
 }
