@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Net.tcl,v $
-# $Date: 1998/07/14 09:32:19 $
-# $Revision: 1.18.1.150 $
+# $Date: 1998/07/16 11:11:14 $
+# $Revision: 1.18.1.151 $
 #
 package provide zircon 1.18
 #
@@ -282,7 +282,7 @@ proc net_startIRC {this srv args} {
     $this show
     set server [$srv host]
     $this configure -ircop 0 -msgQueue {} -msgQTag {} -sysQueue {} \
-      -hostid $srv -motdSeen 0 closing {} -whohandler {}
+      -hostid $srv -motdSeen 0 closing {} -whohandler {} -uhhandler {}
     set ctl [$this control]
     set ost [$ctl openState]
     set ports [$srv selport]
