@@ -1,7 +1,7 @@
 
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/ctcp.tcl,v $
-# $Date: 1998/04/22 08:22:45 $
-# $Revision: 1.18.1.34 $
+# $Source: /home/nlfm/Zircon/lib/RCS/ctcp.tcl,v $
+# $Date: 1998/07/16 11:11:19 $
+# $Revision: 1.18.1.35 $
 #
 package provide zircon 1.18
 #
@@ -39,7 +39,15 @@ proc handleCTCP {net op chid chan usr prefix ign param} {
     CLIENTINFO {
 	    set ctcps {CLIENTINFO VERSION USERINFO ACTION TIME DCC SED ZIRCON}
 	    switch {} [$net wavplayer] {} default {lappend ctcps SOUND}
-	    ctcpReply $net $chan $nk $op "$ctcps: The Zircon IRC client"
+    	    switch {} $param {
+	        set ctcps {CLIENTINFO VERSION USERINFO ACTION TIME DCC SED ZIRCON}
+	        switch {} [$net wavplayer] {} default {lappend ctcps SOUND}
+	        ctcpReply $net $chan $nk $op "$ctcps: The Zircon IRC client"
+	    } default {
+	    	set v No
+		if {[listmember $ctcps $param]} { set v Yes }
+		ctcpReply $net $chan $nk $op "$param : $v"
+	    }
 	}
     VERSION {
 	    switch {} [set v [$net versioninfo]] {
